@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -54,6 +54,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def BindingPolicyTag(self, request):
+        """策略绑定标签
+
+        :param request: Request instance for BindingPolicyTag.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.BindingPolicyTagRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.BindingPolicyTagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BindingPolicyTag", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BindingPolicyTagResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAlarmNotice(self, request):
         """创建通知模板
 
@@ -110,6 +138,36 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateAlertRule(self, request):
+        """创建 Prometheus 告警规则。
+
+        请注意，**告警对象和告警消息是 Prometheus Rule Annotations 的特殊字段，需要通过 annotations 来传递，对应的 Key 分别为summary/description**，，请参考 [Prometheus Rule更多配置请参考](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/)。
+
+        :param request: Request instance for CreateAlertRule.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.CreateAlertRuleRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.CreateAlertRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateAlertRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAlertRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreatePolicyGroup(self, request):
         """增加策略组
 
@@ -224,6 +282,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteAlertRules(self, request):
+        """批量删除 Prometheus 报警规则
+
+        :param request: Request instance for DeleteAlertRules.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.DeleteAlertRulesRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.DeleteAlertRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteAlertRules", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteAlertRulesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeletePolicyGroup(self, request):
         """删除告警策略组
 
@@ -536,6 +622,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAlertRules(self, request):
+        """Prometheus 报警规则查询接口
+
+        :param request: Request instance for DescribeAlertRules.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlertRulesRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.DescribeAlertRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAlertRules", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAlertRulesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAllNamespaces(self, request):
         """查询所有名字空间
 
@@ -816,6 +930,38 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePrometheusInstances(self, request):
+        """本接口 (DescribePrometheusInstances) 用于查询一个或多个实例的详细信息。
+        <ul>
+        <li>可以根据实例ID、实例名称或者实例状态等信息来查询实例的详细信息</li>
+        <li>如果参数为空，返回当前用户一定数量（Limit所指定的数量，默认为20）的实例。</li>
+        </ul>
+
+        :param request: Request instance for DescribePrometheusInstances.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.DescribePrometheusInstancesRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.DescribePrometheusInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePrometheusInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePrometheusInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeServiceDiscovery(self, request):
         """列出在腾讯云容器服务下创建的 Prometheus 服务发现。
         <p>注意：前提条件，已经通过 Prometheus 控制台集成了对应的腾讯云容器服务，具体请参考
@@ -875,7 +1021,8 @@ class MonitorClient(AbstractClient):
 
 
     def GetMonitorData(self, request):
-        """获取云产品的监控数据。传入产品的命名空间、对象维度描述和监控指标即可获得相应的监控数据。
+        """获取云产品的监控数据。此接口不适用于拉取容器服务监控数据，如需拉取容器服务监控数据，请使用[根据维度条件查询监控数据](https://cloud.tencent.com/document/product/248/51845)接口。
+        传入产品的命名空间、对象维度描述和监控指标即可获得相应的监控数据。
         接口调用频率限制为：20次/秒，1200次/分钟。单请求最多可支持批量拉取10个实例的监控数据，单请求的数据点数限制为1440个。
         若您需要调用的指标、对象较多，可能存在因限频出现拉取失败的情况，建议尽量将请求按时间维度均摊。
 
@@ -1275,6 +1422,64 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateAlertRule(self, request):
+        """更新 Prometheus 的报警规则。
+
+        请注意，**告警对象和告警消息是 Prometheus Rule Annotations 的特殊字段，需要通过 annotations 来传递，对应的 Key 分别为summary/description**，，请参考 [Prometheus Rule更多配置请参考](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/)。
+
+        :param request: Request instance for UpdateAlertRule.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.UpdateAlertRuleRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.UpdateAlertRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateAlertRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateAlertRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateAlertRuleState(self, request):
+        """更新 Prometheus 报警策略状态
+
+        :param request: Request instance for UpdateAlertRuleState.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.UpdateAlertRuleStateRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.UpdateAlertRuleStateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateAlertRuleState", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateAlertRuleStateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateServiceDiscovery(self, request):
         """在腾讯云容器服务下更新 Prometheus 服务发现。
         <p>注意：前提条件，已经通过 Prometheus 控制台集成了对应的腾讯云容器服务，具体请参考
